@@ -7,5 +7,5 @@
 class parser_t;
 struct io_streams_t;
 
-maybe_t<int> builtin_read(parser_t &parser, io_streams_t &streams, wchar_t **argv);
+maybe_t<int> builtin_read(parser_t &parser, io_streams_t &streams, const wchar_t **argv);
 #endif
